@@ -56,6 +56,13 @@ input_floats = {
     "fugacity_factor_out",
     "gas_constant",
     "gas_constant_out",
+    # Added in v1.6.0:
+    "total_alpha",
+    "k_alpha",
+    "k_alpha_out",
+    "total_beta",
+    "k_beta",
+    "k_beta_out",
 }
 
 
@@ -111,56 +118,91 @@ def condition(args, to_shape=None):
 
 
 def _get_in_out(core, others, k_constants, suffix=""):
-    return {
-        "pH{}".format(suffix): core["PH"],
-        "pCO2{}".format(suffix): core["PC"] * 1e6,
-        "fCO2{}".format(suffix): core["FC"] * 1e6,
-        "bicarbonate{}".format(suffix): core["HCO3"] * 1e6,
-        "carbonate{}".format(suffix): core["CARB"] * 1e6,
-        "aqueous_CO2{}".format(suffix): core["CO2"] * 1e6,
-        "alkalinity_borate{}".format(suffix): others["BAlk"] * 1e6,
-        "hydroxide{}".format(suffix): others["OH"] * 1e6,
-        "alkalinity_phosphate{}".format(suffix): others["PAlk"] * 1e6,
-        "alkalinity_silicate{}".format(suffix): others["SiAlk"] * 1e6,
-        "alkalinity_ammonia{}".format(suffix): others["NH3Alk"] * 1e6,
-        "alkalinity_sulfide{}".format(suffix): others["H2SAlk"] * 1e6,
-        "hydrogen_free{}".format(suffix): others["Hfree"] * 1e6,
-        "revelle_factor{}".format(suffix): others["Revelle"],
-        "saturation_calcite{}".format(suffix): others["OmegaCa"],
-        "saturation_aragonite{}".format(suffix): others["OmegaAr"],
-        "xCO2{}".format(suffix): others["xCO2dry"] * 1e6,
-        "pH_total{}".format(suffix): others["pHT"],
-        "pH_sws{}".format(suffix): others["pHS"],
-        "pH_free{}".format(suffix): others["pHF"],
-        "pH_nbs{}".format(suffix): others["pHN"],
-        "k_CO2{}".format(suffix): k_constants["K0"],
-        "k_carbonic_1{}".format(suffix): k_constants["K1"],
-        "k_carbonic_2{}".format(suffix): k_constants["K2"],
-        "k_water{}".format(suffix): k_constants["KW"],
-        "k_borate{}".format(suffix): k_constants["KB"],
-        "k_bisulfate{}".format(suffix): k_constants["KSO4"],
-        "k_fluoride{}".format(suffix): k_constants["KF"],
-        "k_phosphoric_1{}".format(suffix): k_constants["KP1"],
-        "k_phosphoric_2{}".format(suffix): k_constants["KP2"],
-        "k_phosphoric_3{}".format(suffix): k_constants["KP3"],
-        "k_silicate{}".format(suffix): k_constants["KSi"],
-        "k_ammonia{}".format(suffix): k_constants["KNH3"],
-        "k_sulfide{}".format(suffix): k_constants["KH2S"],
-        "k_calcite{}".format(suffix): k_constants["KCa"],
-        "k_aragonite{}".format(suffix): k_constants["KAr"],
-        "gamma_dic{}".format(suffix): others["gammaTC"],
-        "beta_dic{}".format(suffix): others["betaTC"],
-        "omega_dic{}".format(suffix): others["omegaTC"],
-        "gamma_alk{}".format(suffix): others["gammaTA"],
-        "beta_alk{}".format(suffix): others["betaTA"],
-        "omega_alk{}".format(suffix): others["omegaTA"],
-        "isocapnic_quotient{}".format(suffix): others["isoQ"],
-        "isocapnic_quotient_approx{}".format(suffix): others["isoQx"],
-        "psi{}".format(suffix): others["psi"],
-        "substrate_inhibitor_ratio{}".format(suffix): others["SIR"],
-        "fugacity_factor{}".format(suffix): k_constants["FugFac"],
-        "fH{}".format(suffix): k_constants["fH"],
+    io = {
+        "pH": core["PH"],
+        "pCO2": core["PC"] * 1e6,
+        "fCO2": core["FC"] * 1e6,
+        "bicarbonate": core["HCO3"] * 1e6,
+        "carbonate": core["CARB"] * 1e6,
+        "aqueous_CO2": core["CO2"] * 1e6,
+        "alkalinity_borate": others["BAlk"] * 1e6,
+        "hydroxide": others["OH"] * 1e6,
+        "alkalinity_phosphate": others["PAlk"] * 1e6,
+        "alkalinity_silicate": others["SiAlk"] * 1e6,
+        "alkalinity_ammonia": others["NH3Alk"] * 1e6,
+        "alkalinity_sulfide": others["H2SAlk"] * 1e6,
+        "hydrogen_free": others["Hfree"] * 1e6,
+        "revelle_factor": others["Revelle"],
+        "saturation_calcite": others["OmegaCa"],
+        "saturation_aragonite": others["OmegaAr"],
+        "xCO2": others["xCO2dry"] * 1e6,
+        "pH_total": others["pHT"],
+        "pH_sws": others["pHS"],
+        "pH_free": others["pHF"],
+        "pH_nbs": others["pHN"],
+        "k_CO2": k_constants["K0"],
+        "k_carbonic_1": k_constants["K1"],
+        "k_carbonic_2": k_constants["K2"],
+        "k_water": k_constants["KW"],
+        "k_borate": k_constants["KB"],
+        "k_bisulfate": k_constants["KSO4"],
+        "k_fluoride": k_constants["KF"],
+        "k_phosphoric_1": k_constants["KP1"],
+        "k_phosphoric_2": k_constants["KP2"],
+        "k_phosphoric_3": k_constants["KP3"],
+        "k_silicate": k_constants["KSi"],
+        "k_ammonia": k_constants["KNH3"],
+        "k_sulfide": k_constants["KH2S"],
+        "k_calcite": k_constants["KCa"],
+        "k_aragonite": k_constants["KAr"],
+        "gamma_dic": others["gammaTC"],
+        "beta_dic": others["betaTC"],
+        "omega_dic": others["omegaTC"],
+        "gamma_alk": others["gammaTA"],
+        "beta_alk": others["betaTA"],
+        "omega_alk": others["omegaTA"],
+        "isocapnic_quotient": others["isoQ"],
+        "isocapnic_quotient_approx": others["isoQx"],
+        "psi": others["psi"],
+        "substrate_inhibitor_ratio": others["SIR"],
+        "fugacity_factor": k_constants["FugFac"],
+        "fH": k_constants["fH"],
+        # Added in v1.6.0:
+        "k_alpha": k_constants["alpha"],
+        "alkalinity_alpha": others["alk_alpha"] * 1e6,
+        "k_beta": k_constants["beta"],
+        "alkalinity_beta": others["alk_beta"] * 1e6,
     }
+    for c in [
+        "HCO3",
+        "CO3",
+        "CO2",
+        "BOH4",
+        "BOH3",
+        "OH",
+        "Hfree",
+        "H3PO4",
+        "H2PO4",
+        "HPO4",
+        "PO4",
+        "H3SiO4",
+        "H4SiO4",
+        "NH3",
+        "NH4",
+        "HS",
+        "H2S",
+        "HSO4",
+        "SO4",
+        "HF",
+        "F",
+        "alpha",
+        "alphaH",
+        "beta",
+        "betaH",
+    ]:
+        if c in others:
+            io[c] = others[c] * 1e6
+    return {"{}{}".format(k, suffix): v for k, v in io.items()}
 
 
 def _get_results_dict(
@@ -201,6 +243,9 @@ def _get_results_dict(
         "gas_constant": k_constants_in["RGas"],
         "alkalinity": core_in["TA"] * 1e6,
         "dic": core_in["TC"] * 1e6,
+        # Added in v1.6.0:
+        "total_alpha": totals["alpha"] * 1e6,
+        "total_beta": totals["beta"] * 1e6,
     }
     results.update(_get_in_out(core_in, others_in, k_constants_in, suffix=""))
     if core_out is not None:
@@ -331,6 +376,38 @@ gradables = [
     "fugacity_factor_out",
     "fH",
     "fH_out",
+    # Added in v1.6.0:
+    "total_alpha",
+    "k_alpha",
+    "k_alpha_out",
+    "total_beta",
+    "k_beta",
+    "k_beta_out",
+    "HCO3",
+    "CO3",
+    "CO2",
+    "BOH4",
+    "BOH3",
+    "OH",
+    "Hfree",
+    "H3PO4",
+    "H2PO4",
+    "HPO4",
+    "PO4",
+    "H3SiO4",
+    "H4SiO4",
+    "NH3",
+    "NH4",
+    "HS",
+    "H2S",
+    "HSO4",
+    "SO4",
+    "HF",
+    "F",
+    "alpha",
+    "alphaH",
+    "beta",
+    "betaH",
 ]
 
 
@@ -357,7 +434,7 @@ def CO2SYS(
     opt_k_carbonic=16,
     opt_k_fluoride=1,
     opt_pH_scale=1,
-    opt_total_borate=2,
+    opt_total_borate=1,
     buffers_mode="auto",
     k_ammonia=None,
     k_ammonia_out=None,
@@ -393,6 +470,13 @@ def CO2SYS(
     fugacity_factor_out=None,
     gas_constant=None,
     gas_constant_out=None,
+    # Added in v1.6.0:
+    total_alpha=None,
+    k_alpha=None,
+    k_alpha_out=None,
+    total_beta=None,
+    k_beta=None,
+    k_beta_out=None,
 ):
     """Run CO2SYS with n-dimensional args allowed."""
     args = condition(locals())
@@ -402,6 +486,8 @@ def CO2SYS(
         "total_calcium": "TCa",
         "total_fluoride": "TF",
         "total_sulfate": "TSO4",
+        "total_alpha": "alpha",
+        "total_beta": "beta",
     }
     if np.any(np.isin(list(args.keys()), list(totals_optional.keys()))):
         totals = {
@@ -440,6 +526,8 @@ def CO2SYS(
         "k_water": "KW",
         "k_calcite": "KCa",
         "k_aragonite": "KAr",
+        "k_alpha": "alpha",
+        "k_beta": "beta",
     }
     if np.any(np.isin(list(args.keys()), list(k_constants_optional.keys()))):
         k_constants_in = {
